#include "word.h"
#include <assert.h>
#include <string.h>
#include <ctype.h>


//-----------------------------------------------------------------------------
word::word() : mWord(new char[max_word_size + 1]), mCount(1)
{
   mWord[max_word_size] = '\0';
}
//-----------------------------------------------------------------------------
word::word(const word &w) : mWord(new char[max_word_size + 1])
{
   assert(w.mWord != nullptr);

   strncpy(mWord, w.mWord, max_word_size);
   mWord[max_word_size] = '\0';
   mCount = w.mCount;
}
//-----------------------------------------------------------------------------
word::~word()
{
  delete[] mWord;
}
//-----------------------------------------------------------------------------
bool word::read_from_file(FILE *f)
{
   assert(f != nullptr);
   if (feof(f)) return false;

   int c;
   size_t i = 0;

   while ((c = fgetc(f)) != EOF)
   {
      if (islower(c)) break;

   }

   while (c != EOF)
   {
      if (islower(c))
      {
         mWord[i] = c;
         ++i;
      }
      else break;

      if (i == max_word_size) break;

      c = fgetc(f);
   }
   mWord[i] = '\0';

   return i > 0;
}
//-----------------------------------------------------------------------------
word &word::operator=(const word &r)
{
   if (r != *this)
   {
      strncpy(mWord, r.mWord, max_word_size);
   }

   mCount = r.mCount;

   return *this;
}
//-----------------------------------------------------------------------------
bool word::operator==(const word &r) const
{
   return strncmp(mWord, r.mWord, max_word_size) == 0;
}
//-----------------------------------------------------------------------------
bool word::operator!=(const word &r) const
{
   return !(*this == r);
}
//-----------------------------------------------------------------------------
bool word::operator<(const word &r) const
{
   return strncmp(mWord, r.mWord, max_word_size) < 0;
}
//-----------------------------------------------------------------------------
bool word::operator>(const word &r) const
{
   return !(*this < r);
}
//-----------------------------------------------------------------------------
void word::print() const
{
   printf("%s - %d\n", mWord, mCount);
}
//-----------------------------------------------------------------------------
const char *word::get() const
{
   return mWord;
}
//-----------------------------------------------------------------------------
size_t word::count() const
{
   return mCount;
}
//-----------------------------------------------------------------------------
size_t word::inc_count(size_t i)
{
   mCount += i;
   return mCount;
}
//-----------------------------------------------------------------------------
